========================
dj-pagination
========================

.. image:: https://travis-ci.org/pydanny/dj-pagination.svg?branch=master
    :target: https://travis-ci.org/pydanny/dj-pagination

.. image:: http://codecov.io/github/pydanny/dj-pagination/badge.svg?branch=master&service=github
    :target: https://codecov.io/github/pydanny/django-pagination?branch=master


About the fork
--------------

This project is a fork of the "django-pagination" project
originally written by 'Eric Florenzano' then forked by the Linaro
Validation/Infrastructure team. Latest releases can be found on pypi.


About top-level package name change
-----------------------------------
The top level package name was changed from `pagination` to
`linaro_django_pagination` to `dj_pagination`. Following the Linaro pattern
I did this to ensure that existing users of the original package could easily
transition, on their own terms. Since both packages are co-installable you
are free to check things out and see if the new pagination code works well for
you or not.

Since the implementation of the actual tags were rewritten since the
django-pagination days it's fairly certain the new package is a NOT a
drop-in replacement.


Contributors
------------

We would like to welcome any and all contributors. Please use the pull request
feature on github.


How to use dj-pagination
-----------------------------------

See our official documentation for more details.
http://dj-pagination.readthedocs.io/
